@@ -62,10 +62,24 @@ def get_distinguish_unit(line, program_ast):
 def lines_variable_changed(variable_id, program_file):
     lines = []
     program = open(program_file, 'r')
-    change_pattern = variable_id + r'[\s]*=.*\n'
+    assign_pat = variable_id + r'[\s]*(\+|\-|\*|\/)?=.*\n'
+    # Mutable sequences in Python
+    list_mutation_pat = variable_id + r'\.(append|extend|insert|remove|pop|reverse)(.)*\n'
+    dict_mutation_pat = variable_id + r'\[[\"a-zA-Z0-9]+\](\s)?(\+|\-|\*|\/)?='
+    set_mutation_pat = variable_id + r'\.(update|intersection_update|difference_update|add|remove|discard|pop|clear)(.)*\n'
+    key_del_pat = r'del[\s]?' + variable_id
     for line_num, line_content in enumerate(program.readlines()):
-        match = re.search(change_pattern, line_content)
-        if match:
+        assign = re.search(assign_pat, line_content)
+        list_mutation = re.search(list_mutation_pat, line_content)
+        dict_mutation = re.search(dict_mutation_pat, line_content)
+        dict_key_deleted = re.search(key_del_pat, line_content)
+        set_mutation = re.search(set_mutation_pat, line_content)
+        changed = (assign or
+                   list_mutation or
+                   dict_mutation or
+                   dict_key_deleted or
+                   set_mutation)
+        if changed:
             lines.append(line_num)
     program.close()
     return lines
